@@ -1,21 +1,9 @@
-/* This file is part of the KDE libraries
-    Copyright (C) 2000 Stephan Kulow <coolo@kde.org>
-                  2000-2013 David Faure <faure@kde.org>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2000 Stephan Kulow <coolo@kde.org>
+    SPDX-FileCopyrightText: 2000-2013 David Faure <faure@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KIO_STATJOB_H
@@ -27,7 +15,6 @@
 
 namespace KIO
 {
-
 class StatJobPrivate;
 /**
  * @class KIO::StatJob statjob.h <KIO/StatJob>
@@ -37,13 +24,12 @@ class StatJobPrivate;
  */
 class KIOCORE_EXPORT StatJob : public SimpleJob
 {
-
     Q_OBJECT
 
 public:
     enum StatSide {
         SourceSide,
-        DestinationSide
+        DestinationSide,
     };
 
     ~StatJob() override;
@@ -51,7 +37,7 @@ public:
     /**
      * A stat() can have two meanings. Either we want to read from this URL,
      * or to check if we can write to it. First case is "source", second is "dest".
-     * It is necessary to know what the StatJob is for, to tune the kioslave's behavior
+     * It is necessary to know what the StatJob is for, to tune the KIO worker's behavior
      * (e.g. with FTP).
      * By default it is SourceSide.
      * @param side SourceSide or DestinationSide
@@ -62,7 +48,7 @@ public:
     /**
      * A stat() can have two meanings. Either we want to read from this URL,
      * or to check if we can write to it. First case is "source", second is "dest".
-     * It is necessary to know what the StatJob is for, to tune the kioslave's behavior
+     * It is necessary to know what the StatJob is for, to tune the KIO worker's behavior
      * (e.g. with FTP).
      * @param source true for "source" mode, false for "dest" mode
      * @deprecated Since 4.0, use setSide(StatSide side).
@@ -109,6 +95,11 @@ public:
     /**
      * @brief most local URL
      *
+     * Since this method depends on UDSEntry::UDS_LOCAL_PATH having been previously set
+     * by a KIO worker, ideally you should first check that the protocol Class of the URL
+     * being stat'ed is ":local" before creating the StatJob at all. Typically only ":local"
+     * KIO workers set UDS_LOCAL_PATH. See KProtocolInfo::protocolClass().
+     *
      * Call this in a slot connected to the result signal, and only after making sure no error
      * happened.
      *
@@ -117,7 +108,7 @@ public:
      * Sample usage:
      *
      * @code
-     * KIO::StatJob *job = KIO::mostLocalUrl("desktop:/foo");
+     * auto *job = KIO::mostLocalUrl("desktop:/foo");
      * job->uiDelegate()->setWindow(this);
      * connect(job, &KJob::result, this, &MyClass::slotMostLocalUrlResult);
      * [...]
@@ -156,13 +147,14 @@ Q_SIGNALS:
 
 protected Q_SLOTS:
     void slotFinished() override;
+#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 101) // override no longer needed
     void slotMetaData(const KIO::MetaData &_metaData) override;
+#endif
+
 protected:
     StatJob(StatJobPrivate &dd);
 
 private:
-    Q_PRIVATE_SLOT(d_func(), void slotStatEntry(const KIO::UDSEntry &entry))
-    Q_PRIVATE_SLOT(d_func(), void slotRedirection(const QUrl &url))
     Q_DECLARE_PRIVATE(StatJob)
     friend KIOCORE_EXPORT StatJob *mostLocalUrl(const QUrl &url, JobFlags flags);
 };
@@ -182,10 +174,10 @@ KIOCORE_EXPORT StatJob *stat(const QUrl &url, JobFlags flags = DefaultFlags);
  * @param url the URL of the file
  * @param side is SourceSide when stating a source file (we will do a get on it if
  * the stat works) and DestinationSide when stating a destination file (target of a copy).
- * The reason for this parameter is that in some cases the kioslave might not
+ * The reason for this parameter is that in some cases the KIO worker might not
  * be able to determine a file's existence (e.g. HTTP doesn't allow it, FTP
  * has issues with case-sensitivity on some systems).
- * When the slave can't reliably determine the existence of a file, it will:
+ * When the worker can't reliably determine the existence of a file, it will:
  * @li be optimistic if SourceSide, i.e. it will assume the file exists,
  * and if it doesn't this will appear when actually trying to download it
  * @li be pessimistic if DestinationSide, i.e. it will assume the file
@@ -199,8 +191,8 @@ KIOCORE_EXPORT StatJob *stat(const QUrl &url, JobFlags flags = DefaultFlags);
  * @return the job handling the operation.
  * @since 5.69
  */
-KIOCORE_EXPORT StatJob *statDetails(const QUrl &url, KIO::StatJob::StatSide side,
-                             KIO::StatDetails details = KIO::StatDefaultDetails, JobFlags flags = DefaultFlags);
+KIOCORE_EXPORT StatJob *
+statDetails(const QUrl &url, KIO::StatJob::StatSide side, KIO::StatDetails details = KIO::StatDefaultDetails, JobFlags flags = DefaultFlags);
 
 #if KIOCORE_ENABLE_DEPRECATED_SINCE(5, 69)
 /**
@@ -210,10 +202,10 @@ KIOCORE_EXPORT StatJob *statDetails(const QUrl &url, KIO::StatJob::StatSide side
  * @param url the URL of the file
  * @param side is SourceSide when stating a source file (we will do a get on it if
  * the stat works) and DestinationSide when stating a destination file (target of a copy).
- * The reason for this parameter is that in some cases the kioslave might not
+ * The reason for this parameter is that in some cases the KIO worker might not
  * be able to determine a file's existence (e.g. HTTP doesn't allow it, FTP
  * has issues with case-sensitivity on some systems).
- * When the slave can't reliably determine the existence of a file, it will:
+ * When the worker can't reliably determine the existence of a file, it will:
  * @li be optimistic if SourceSide, i.e. it will assume the file exists,
  * and if it doesn't this will appear when actually trying to download it
  * @li be pessimistic if DestinationSide, i.e. it will assume the file
@@ -231,9 +223,9 @@ KIOCORE_EXPORT StatJob *statDetails(const QUrl &url, KIO::StatJob::StatSide side
  * @return the job handling the operation.
  * @deprecated since 5.69, use statDetails(const QUrl &, KIO::StatJob::StatSide, KIO::StatDetails, JobFlags)
  */
+KIOCORE_EXPORT
 KIOCORE_DEPRECATED_VERSION(5, 69, "Use KIO::statDetails(const QUrl &, KIO::StatJob::StatSide, KIO::StatDetails, JobFlags)")
-KIOCORE_EXPORT StatJob *stat(const QUrl &url, KIO::StatJob::StatSide side,
-                             short int details, JobFlags flags = DefaultFlags);
+StatJob *stat(const QUrl &url, KIO::StatJob::StatSide side, short int details, JobFlags flags = DefaultFlags);
 #endif
 
 #if KIOCORE_ENABLE_DEPRECATED_SINCE(5, 69)
@@ -243,8 +235,9 @@ KIOCORE_EXPORT StatJob *stat(const QUrl &url, KIO::StatJob::StatSide side,
  * @since 5.69
  * @deprecated since 5.69, use directly KIO::StatDetails
  */
+KIOCORE_EXPORT
 KIOCORE_DEPRECATED_VERSION(5, 69, "Use directly KIO::StatDetails")
-KIOCORE_EXPORT KIO::StatDetails detailsToStatDetails(int details);
+KIO::StatDetails detailsToStatDetails(int details);
 #endif
 
 #if KIOCORE_ENABLE_DEPRECATED_SINCE(4, 0)
@@ -255,10 +248,10 @@ KIOCORE_EXPORT KIO::StatDetails detailsToStatDetails(int details);
  * @param url the URL of the file
  * @param sideIsSource is true when stating a source file (we will do a get on it if
  * the stat works) and false when stating a destination file (target of a copy).
- * The reason for this parameter is that in some cases the kioslave might not
+ * The reason for this parameter is that in some cases the KIO worker might not
  * be able to determine a file's existence (e.g. HTTP doesn't allow it, FTP
  * has issues with case-sensitivity on some systems).
- * When the slave can't reliably determine the existence of a file, it will:
+ * When the worker can't reliably determine the existence of a file, it will:
  * @li be optimistic if sideIsSource=true, i.e. it will assume the file exists,
  * and if it doesn't this will appear when actually trying to download it
  * @li be pessimistic if sideIsSource=false, i.e. it will assume the file
@@ -276,18 +269,54 @@ KIOCORE_EXPORT KIO::StatDetails detailsToStatDetails(int details);
  * @return the job handling the operation.
  * @deprecated Since 4.0, use stat(const QUrl &, KIO::StatJob::StatSide, short int, JobFlags)
  */
+KIOCORE_EXPORT
 KIOCORE_DEPRECATED_VERSION(4, 0, "Use KIO::stat(const QUrl &, KIO::StatJob::StatSide, short int, JobFlags)")
-KIOCORE_EXPORT StatJob *stat(const QUrl &url, bool sideIsSource,
-                             short int details, JobFlags flags = DefaultFlags);
+StatJob *stat(const QUrl &url, bool sideIsSource, short int details, JobFlags flags = DefaultFlags);
 #endif
 
 /**
- * Tries to map a local URL for the given URL, using a KIO job.
+ * Tries to map a local URL for the given URL, using a KIO job. This only makes sense for
+ * protocols that have Class ":local" (such protocols most likely have KIO workers that set
+ * UDSEntry::UDS_LOCAL_PATH); ideally you should check the URL protocol Class before creating
+ * a StatJob. See KProtocolInfo::protocolClass().
  *
  * Starts a (stat) job for determining the "most local URL" for a given URL.
  * Retrieve the result with StatJob::mostLocalUrl in the result slot.
- * @param url The URL we are testing.
- * \since 4.4
+ *
+ * @param url The URL we are stat'ing.
+ *
+ * @since 4.4
+ *
+ * Sample usage:
+ *
+ * Here the KIO worker name is "foo", which for example could be:
+ *  - "desktop", "fonts", "kdeconnect", these have class ":local"
+ *  - "ftp", "sftp", "smb", these have class ":internet"
+ *
+ * @code
+ *
+ * QUrl url(QStringLiteral("foo://bar/");
+ * if (url.isLocalFile()) { // If it's a local URL, there is no need to stat
+ *    [...]
+ * } else if (KProtocolInfo::protocolClass(url.scheme()) == QLatin1String(":local")) {
+ *     // Not a local URL, but if the protocol class is ":local", we may be able to stat
+ *     // and get a "most local URL"
+ *     auto *job = KIO::mostLocalUrl(url);
+ *     job->uiDelegate()->setWindow(this);
+ *     connect(job, &KJob::result, this, &MyClass::slotMostLocalUrlResult);
+ *     [...]
+ *     // And in slotMostLocalUrlResult(KJob *job)
+ *     if (job->error()) {
+ *         [...] // Doesn't exist, ideally show an error message
+ *     } else {
+ *         const QUrl localUrl = job->mostLocalUrl();
+ *         // localUrl = file:///local/path/to/bar/
+ *         [...]
+ *     }
+ * }
+ *
+ * @endcode
+ *
  */
 KIOCORE_EXPORT StatJob *mostLocalUrl(const QUrl &url, JobFlags flags = DefaultFlags);
 
