@@ -86,7 +86,7 @@
 #define KIOFILEWIDGETS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KIOFILEWIDGETS_NO_DEPRECATED
-#  define KIOFILEWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56200
+#  define KIOFILEWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56700
 #endif
 #ifdef KIOFILEWIDGETS_NO_DEPRECATED_WARNINGS
 #  define KIOFILEWIDGETS_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KIOFILEWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KIOFILEWIDGETS_DEPRECATED_WARNINGS_SINCE KIOFILEWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KIOFILEWIDGETS_DEPRECATED_WARNINGS_SINCE 0x56200
+#    define KIOFILEWIDGETS_DEPRECATED_WARNINGS_SINCE 0x56700
 #  endif
 #endif
 
@@ -169,6 +169,18 @@
 #else
 #  define KIOFILEWIDGETS_DEPRECATED_VERSION_5_97(text)
 #endif
+
+#if KIOFILEWIDGETS_DEPRECATED_WARNINGS_SINCE >= 0x56400
+#  define KIOFILEWIDGETS_DEPRECATED_VERSION_5_100(text) KIOFILEWIDGETS_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KIOFILEWIDGETS_DEPRECATED_VERSION_5_100(text)
+#endif
+
+#if KIOFILEWIDGETS_DEPRECATED_WARNINGS_SINCE >= 0x56700
+#  define KIOFILEWIDGETS_DEPRECATED_VERSION_5_103(text) KIOFILEWIDGETS_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KIOFILEWIDGETS_DEPRECATED_VERSION_5_103(text)
+#endif
 #define KIOFILEWIDGETS_DEPRECATED_VERSION_4(minor, text)      KIOFILEWIDGETS_DEPRECATED_VERSION_4_##minor(text)
 #define KIOFILEWIDGETS_DEPRECATED_VERSION_5(minor, text)      KIOFILEWIDGETS_DEPRECATED_VERSION_5_##minor(text)
 #define KIOFILEWIDGETS_DEPRECATED_VERSION(major, minor, text) KIOFILEWIDGETS_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
@@ -235,7 +247,7 @@
 #define KIOFILEWIDGETS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KIOFILEWIDGETS_NO_DEPRECATED
-#  define KIOFILEWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56200
+#  define KIOFILEWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56700
 #endif
 #ifdef KIOFILEWIDGETS_NO_DEPRECATED_WARNINGS
 #  define KIOFILEWIDGETS_DEPRECATED_WARNINGS_SINCE 0
@@ -245,7 +257,7 @@
 #  ifdef KIOFILEWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KIOFILEWIDGETS_DEPRECATED_WARNINGS_SINCE KIOFILEWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KIOFILEWIDGETS_DEPRECATED_WARNINGS_SINCE 0x56200
+#    define KIOFILEWIDGETS_DEPRECATED_WARNINGS_SINCE 0x56700
 #  endif
 #endif
 
@@ -318,6 +330,18 @@
 #else
 #  define KIOFILEWIDGETS_DEPRECATED_VERSION_5_97(text)
 #endif
+
+#if KIOFILEWIDGETS_DEPRECATED_WARNINGS_SINCE >= 0x56400
+#  define KIOFILEWIDGETS_DEPRECATED_VERSION_5_100(text) KIOFILEWIDGETS_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KIOFILEWIDGETS_DEPRECATED_VERSION_5_100(text)
+#endif
+
+#if KIOFILEWIDGETS_DEPRECATED_WARNINGS_SINCE >= 0x56700
+#  define KIOFILEWIDGETS_DEPRECATED_VERSION_5_103(text) KIOFILEWIDGETS_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KIOFILEWIDGETS_DEPRECATED_VERSION_5_103(text)
+#endif
 #define KIOFILEWIDGETS_DEPRECATED_VERSION_4(minor, text)      KIOFILEWIDGETS_DEPRECATED_VERSION_4_##minor(text)
 #define KIOFILEWIDGETS_DEPRECATED_VERSION_5(minor, text)      KIOFILEWIDGETS_DEPRECATED_VERSION_5_##minor(text)
 #define KIOFILEWIDGETS_DEPRECATED_VERSION(major, minor, text) KIOFILEWIDGETS_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
