@@ -86,7 +86,7 @@
 #define KIOWIDGETS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KIOWIDGETS_NO_DEPRECATED
-#  define KIOWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56200
+#  define KIOWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56700
 #endif
 #ifdef KIOWIDGETS_NO_DEPRECATED_WARNINGS
 #  define KIOWIDGETS_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KIOWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KIOWIDGETS_DEPRECATED_WARNINGS_SINCE KIOWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KIOWIDGETS_DEPRECATED_WARNINGS_SINCE 0x56200
+#    define KIOWIDGETS_DEPRECATED_WARNINGS_SINCE 0x56700
 #  endif
 #endif
 
@@ -271,6 +271,24 @@
 #else
 #  define KIOWIDGETS_DEPRECATED_VERSION_5_98(text)
 #endif
+
+#if KIOWIDGETS_DEPRECATED_WARNINGS_SINCE >= 0x56500
+#  define KIOWIDGETS_DEPRECATED_VERSION_5_101(text) KIOWIDGETS_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KIOWIDGETS_DEPRECATED_VERSION_5_101(text)
+#endif
+
+#if KIOWIDGETS_DEPRECATED_WARNINGS_SINCE >= 0x56600
+#  define KIOWIDGETS_DEPRECATED_VERSION_5_102(text) KIOWIDGETS_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KIOWIDGETS_DEPRECATED_VERSION_5_102(text)
+#endif
+
+#if KIOWIDGETS_DEPRECATED_WARNINGS_SINCE >= 0x56700
+#  define KIOWIDGETS_DEPRECATED_VERSION_5_103(text) KIOWIDGETS_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KIOWIDGETS_DEPRECATED_VERSION_5_103(text)
+#endif
 #define KIOWIDGETS_DEPRECATED_VERSION_4(minor, text)      KIOWIDGETS_DEPRECATED_VERSION_4_##minor(text)
 #define KIOWIDGETS_DEPRECATED_VERSION_5(minor, text)      KIOWIDGETS_DEPRECATED_VERSION_5_##minor(text)
 #define KIOWIDGETS_DEPRECATED_VERSION(major, minor, text) KIOWIDGETS_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
@@ -337,7 +355,7 @@
 #define KIOWIDGETS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KIOWIDGETS_NO_DEPRECATED
-#  define KIOWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56200
+#  define KIOWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56700
 #endif
 #ifdef KIOWIDGETS_NO_DEPRECATED_WARNINGS
 #  define KIOWIDGETS_DEPRECATED_WARNINGS_SINCE 0
@@ -347,7 +365,7 @@
 #  ifdef KIOWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KIOWIDGETS_DEPRECATED_WARNINGS_SINCE KIOWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KIOWIDGETS_DEPRECATED_WARNINGS_SINCE 0x56200
+#    define KIOWIDGETS_DEPRECATED_WARNINGS_SINCE 0x56700
 #  endif
 #endif
 
@@ -522,6 +540,24 @@
 #else
 #  define KIOWIDGETS_DEPRECATED_VERSION_5_98(text)
 #endif
+
+#if KIOWIDGETS_DEPRECATED_WARNINGS_SINCE >= 0x56500
+#  define KIOWIDGETS_DEPRECATED_VERSION_5_101(text) KIOWIDGETS_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KIOWIDGETS_DEPRECATED_VERSION_5_101(text)
+#endif
+
+#if KIOWIDGETS_DEPRECATED_WARNINGS_SINCE >= 0x56600
+#  define KIOWIDGETS_DEPRECATED_VERSION_5_102(text) KIOWIDGETS_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KIOWIDGETS_DEPRECATED_VERSION_5_102(text)
+#endif
+
+#if KIOWIDGETS_DEPRECATED_WARNINGS_SINCE >= 0x56700
+#  define KIOWIDGETS_DEPRECATED_VERSION_5_103(text) KIOWIDGETS_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KIOWIDGETS_DEPRECATED_VERSION_5_103(text)
+#endif
 #define KIOWIDGETS_DEPRECATED_VERSION_4(minor, text)      KIOWIDGETS_DEPRECATED_VERSION_4_##minor(text)
 #define KIOWIDGETS_DEPRECATED_VERSION_5(minor, text)      KIOWIDGETS_DEPRECATED_VERSION_5_##minor(text)
 #define KIOWIDGETS_DEPRECATED_VERSION(major, minor, text) KIOWIDGETS_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
